@@ -1,3 +1,6 @@
+#ifdef __cplusplus
+extern "C" {
+#endif
 #ifndef _MKDIO_D
 #define _MKDIO_D
 
@@ -5,7 +8,7 @@
 
 typedef void MMIOT;
 
-typedef unsigned int mkd_flag_t;
+typedef unsigned long mkd_flag_t;
 
 /* line builder for markdown()
  */
@@ -122,3 +125,6 @@ void mkd_ref_prefix(MMIOT*, char*);
 
 
 #endif/*_MKDIO_D*/
+#ifdef __cplusplus
+}
+#endif
